@@ -5,11 +5,12 @@ from peek_plugin_gis_diagram._private.PluginNames import gisDiagramTuplePrefix
 
 @addTupleType
 class GisDiagramTuple(Tuple):
-    """ GisDiagram Tuple
+    """GisDiagram Tuple
 
     This tuple is a create example of defining classes to work with our data.
     """
-    __tupleType__ = gisDiagramTuplePrefix + 'GisDiagramTuple'
+
+    __tupleType__ = gisDiagramTuplePrefix + "GisDiagramTuple"
 
     #:  Description of date1
     dict1 = TupleField(defaultValue=dict)
